package SPVM::Net::SSLeay::Constant;



1;

=head1 Name

SPVM::Net::SSLeay::Constant - Short Description

=head1 Description

The Net::SSLeay::Constant class of L<SPVM> has methods for someting.

=head1 Usage

  use Net::SSLeay::Constant;

=head1 Class Methods

=head2 ASN1_STRFLGS_ESC_CTRL

  static method ASN1_STRFLGS_ESC_CTRL : int ();

Gets the value of C<ASN1_STRFLGS_ESC_CTRL>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 ASN1_STRFLGS_ESC_MSB

  static method ASN1_STRFLGS_ESC_MSB : int ();

Gets the value of C<ASN1_STRFLGS_ESC_MSB>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 ASN1_STRFLGS_ESC_QUOTE

  static method ASN1_STRFLGS_ESC_QUOTE : int ();

Gets the value of C<ASN1_STRFLGS_ESC_QUOTE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 ASN1_STRFLGS_RFC2253

  static method ASN1_STRFLGS_RFC2253 : int ();

Gets the value of C<ASN1_STRFLGS_RFC2253>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 EVP_PKS_DSA

  static method EVP_PKS_DSA : int ();

Gets the value of C<EVP_PKS_DSA>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 EVP_PKS_EC

  static method EVP_PKS_EC : int ();

Gets the value of C<EVP_PKS_EC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 EVP_PKS_RSA

  static method EVP_PKS_RSA : int ();

Gets the value of C<EVP_PKS_RSA>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 EVP_PKT_ENC

  static method EVP_PKT_ENC : int ();

Gets the value of C<EVP_PKT_ENC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 EVP_PKT_EXCH

  static method EVP_PKT_EXCH : int ();

Gets the value of C<EVP_PKT_EXCH>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 EVP_PKT_EXP

  static method EVP_PKT_EXP : int ();

Gets the value of C<EVP_PKT_EXP>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 EVP_PKT_SIGN

  static method EVP_PKT_SIGN : int ();

Gets the value of C<EVP_PKT_SIGN>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 EVP_PK_DH

  static method EVP_PK_DH : int ();

Gets the value of C<EVP_PK_DH>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 EVP_PK_DSA

  static method EVP_PK_DSA : int ();

Gets the value of C<EVP_PK_DSA>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 EVP_PK_EC

  static method EVP_PK_EC : int ();

Gets the value of C<EVP_PK_EC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 EVP_PK_RSA

  static method EVP_PK_RSA : int ();

Gets the value of C<EVP_PK_RSA>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 GEN_DIRNAME

  static method GEN_DIRNAME : int ();

Gets the value of C<GEN_DIRNAME>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 GEN_DNS

  static method GEN_DNS : int ();

Gets the value of C<GEN_DNS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 GEN_EDIPARTY

  static method GEN_EDIPARTY : int ();

Gets the value of C<GEN_EDIPARTY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 GEN_EMAIL

  static method GEN_EMAIL : int ();

Gets the value of C<GEN_EMAIL>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 GEN_IPADD

  static method GEN_IPADD : int ();

Gets the value of C<GEN_IPADD>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 GEN_OTHERNAME

  static method GEN_OTHERNAME : int ();

Gets the value of C<GEN_OTHERNAME>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 GEN_RID

  static method GEN_RID : int ();

Gets the value of C<GEN_RID>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 GEN_URI

  static method GEN_URI : int ();

Gets the value of C<GEN_URI>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 GEN_X400

  static method GEN_X400 : int ();

Gets the value of C<GEN_X400>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 LIBRESSL_VERSION_NUMBER

  static method LIBRESSL_VERSION_NUMBER : int ();

Gets the value of C<LIBRESSL_VERSION_NUMBER>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 MBSTRING_ASC

  static method MBSTRING_ASC : int ();

Gets the value of C<MBSTRING_ASC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 MBSTRING_BMP

  static method MBSTRING_BMP : int ();

Gets the value of C<MBSTRING_BMP>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 MBSTRING_FLAG

  static method MBSTRING_FLAG : int ();

Gets the value of C<MBSTRING_FLAG>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 MBSTRING_UNIV

  static method MBSTRING_UNIV : int ();

Gets the value of C<MBSTRING_UNIV>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 MBSTRING_UTF8

  static method MBSTRING_UTF8 : int ();

Gets the value of C<MBSTRING_UTF8>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_OCSP_sign

  static method NID_OCSP_sign : int ();

Gets the value of C<NID_OCSP_sign>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_SMIMECapabilities

  static method NID_SMIMECapabilities : int ();

Gets the value of C<NID_SMIMECapabilities>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_X500

  static method NID_X500 : int ();

Gets the value of C<NID_X500>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_X509

  static method NID_X509 : int ();

Gets the value of C<NID_X509>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_ad_OCSP

  static method NID_ad_OCSP : int ();

Gets the value of C<NID_ad_OCSP>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_ad_ca_issuers

  static method NID_ad_ca_issuers : int ();

Gets the value of C<NID_ad_ca_issuers>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_algorithm

  static method NID_algorithm : int ();

Gets the value of C<NID_algorithm>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_authority_key_identifier

  static method NID_authority_key_identifier : int ();

Gets the value of C<NID_authority_key_identifier>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_basic_constraints

  static method NID_basic_constraints : int ();

Gets the value of C<NID_basic_constraints>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_bf_cbc

  static method NID_bf_cbc : int ();

Gets the value of C<NID_bf_cbc>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_bf_cfb64

  static method NID_bf_cfb64 : int ();

Gets the value of C<NID_bf_cfb64>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_bf_ecb

  static method NID_bf_ecb : int ();

Gets the value of C<NID_bf_ecb>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_bf_ofb64

  static method NID_bf_ofb64 : int ();

Gets the value of C<NID_bf_ofb64>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_cast5_cbc

  static method NID_cast5_cbc : int ();

Gets the value of C<NID_cast5_cbc>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_cast5_cfb64

  static method NID_cast5_cfb64 : int ();

Gets the value of C<NID_cast5_cfb64>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_cast5_ecb

  static method NID_cast5_ecb : int ();

Gets the value of C<NID_cast5_ecb>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_cast5_ofb64

  static method NID_cast5_ofb64 : int ();

Gets the value of C<NID_cast5_ofb64>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_certBag

  static method NID_certBag : int ();

Gets the value of C<NID_certBag>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_certificate_policies

  static method NID_certificate_policies : int ();

Gets the value of C<NID_certificate_policies>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_client_auth

  static method NID_client_auth : int ();

Gets the value of C<NID_client_auth>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_code_sign

  static method NID_code_sign : int ();

Gets the value of C<NID_code_sign>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_commonName

  static method NID_commonName : int ();

Gets the value of C<NID_commonName>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_countryName

  static method NID_countryName : int ();

Gets the value of C<NID_countryName>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_crlBag

  static method NID_crlBag : int ();

Gets the value of C<NID_crlBag>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_crl_distribution_points

  static method NID_crl_distribution_points : int ();

Gets the value of C<NID_crl_distribution_points>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_crl_number

  static method NID_crl_number : int ();

Gets the value of C<NID_crl_number>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_crl_reason

  static method NID_crl_reason : int ();

Gets the value of C<NID_crl_reason>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_delta_crl

  static method NID_delta_crl : int ();

Gets the value of C<NID_delta_crl>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_des_cbc

  static method NID_des_cbc : int ();

Gets the value of C<NID_des_cbc>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_des_cfb64

  static method NID_des_cfb64 : int ();

Gets the value of C<NID_des_cfb64>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_des_ecb

  static method NID_des_ecb : int ();

Gets the value of C<NID_des_ecb>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_des_ede

  static method NID_des_ede : int ();

Gets the value of C<NID_des_ede>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_des_ede3

  static method NID_des_ede3 : int ();

Gets the value of C<NID_des_ede3>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_des_ede3_cbc

  static method NID_des_ede3_cbc : int ();

Gets the value of C<NID_des_ede3_cbc>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_des_ede3_cfb64

  static method NID_des_ede3_cfb64 : int ();

Gets the value of C<NID_des_ede3_cfb64>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_des_ede3_ofb64

  static method NID_des_ede3_ofb64 : int ();

Gets the value of C<NID_des_ede3_ofb64>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_des_ede_cbc

  static method NID_des_ede_cbc : int ();

Gets the value of C<NID_des_ede_cbc>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_des_ede_cfb64

  static method NID_des_ede_cfb64 : int ();

Gets the value of C<NID_des_ede_cfb64>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_des_ede_ofb64

  static method NID_des_ede_ofb64 : int ();

Gets the value of C<NID_des_ede_ofb64>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_des_ofb64

  static method NID_des_ofb64 : int ();

Gets the value of C<NID_des_ofb64>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_description

  static method NID_description : int ();

Gets the value of C<NID_description>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_desx_cbc

  static method NID_desx_cbc : int ();

Gets the value of C<NID_desx_cbc>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_dhKeyAgreement

  static method NID_dhKeyAgreement : int ();

Gets the value of C<NID_dhKeyAgreement>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_dnQualifier

  static method NID_dnQualifier : int ();

Gets the value of C<NID_dnQualifier>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_dsa

  static method NID_dsa : int ();

Gets the value of C<NID_dsa>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_dsaWithSHA

  static method NID_dsaWithSHA : int ();

Gets the value of C<NID_dsaWithSHA>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_dsaWithSHA1

  static method NID_dsaWithSHA1 : int ();

Gets the value of C<NID_dsaWithSHA1>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_dsaWithSHA1_2

  static method NID_dsaWithSHA1_2 : int ();

Gets the value of C<NID_dsaWithSHA1_2>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_dsa_2

  static method NID_dsa_2 : int ();

Gets the value of C<NID_dsa_2>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_email_protect

  static method NID_email_protect : int ();

Gets the value of C<NID_email_protect>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_ext_key_usage

  static method NID_ext_key_usage : int ();

Gets the value of C<NID_ext_key_usage>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_ext_req

  static method NID_ext_req : int ();

Gets the value of C<NID_ext_req>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_friendlyName

  static method NID_friendlyName : int ();

Gets the value of C<NID_friendlyName>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_givenName

  static method NID_givenName : int ();

Gets the value of C<NID_givenName>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_hmacWithSHA1

  static method NID_hmacWithSHA1 : int ();

Gets the value of C<NID_hmacWithSHA1>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_id_ad

  static method NID_id_ad : int ();

Gets the value of C<NID_id_ad>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_id_ce

  static method NID_id_ce : int ();

Gets the value of C<NID_id_ce>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_id_kp

  static method NID_id_kp : int ();

Gets the value of C<NID_id_kp>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_id_pbkdf2

  static method NID_id_pbkdf2 : int ();

Gets the value of C<NID_id_pbkdf2>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_id_pe

  static method NID_id_pe : int ();

Gets the value of C<NID_id_pe>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_id_pkix

  static method NID_id_pkix : int ();

Gets the value of C<NID_id_pkix>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_id_qt_cps

  static method NID_id_qt_cps : int ();

Gets the value of C<NID_id_qt_cps>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_id_qt_unotice

  static method NID_id_qt_unotice : int ();

Gets the value of C<NID_id_qt_unotice>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_idea_cbc

  static method NID_idea_cbc : int ();

Gets the value of C<NID_idea_cbc>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_idea_cfb64

  static method NID_idea_cfb64 : int ();

Gets the value of C<NID_idea_cfb64>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_idea_ecb

  static method NID_idea_ecb : int ();

Gets the value of C<NID_idea_ecb>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_idea_ofb64

  static method NID_idea_ofb64 : int ();

Gets the value of C<NID_idea_ofb64>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_info_access

  static method NID_info_access : int ();

Gets the value of C<NID_info_access>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_initials

  static method NID_initials : int ();

Gets the value of C<NID_initials>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_invalidity_date

  static method NID_invalidity_date : int ();

Gets the value of C<NID_invalidity_date>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_issuer_alt_name

  static method NID_issuer_alt_name : int ();

Gets the value of C<NID_issuer_alt_name>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_keyBag

  static method NID_keyBag : int ();

Gets the value of C<NID_keyBag>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_key_usage

  static method NID_key_usage : int ();

Gets the value of C<NID_key_usage>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_localKeyID

  static method NID_localKeyID : int ();

Gets the value of C<NID_localKeyID>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_localityName

  static method NID_localityName : int ();

Gets the value of C<NID_localityName>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_md2

  static method NID_md2 : int ();

Gets the value of C<NID_md2>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_md2WithRSAEncryption

  static method NID_md2WithRSAEncryption : int ();

Gets the value of C<NID_md2WithRSAEncryption>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_md5

  static method NID_md5 : int ();

Gets the value of C<NID_md5>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_md5WithRSA

  static method NID_md5WithRSA : int ();

Gets the value of C<NID_md5WithRSA>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_md5WithRSAEncryption

  static method NID_md5WithRSAEncryption : int ();

Gets the value of C<NID_md5WithRSAEncryption>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_md5_sha1

  static method NID_md5_sha1 : int ();

Gets the value of C<NID_md5_sha1>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_mdc2

  static method NID_mdc2 : int ();

Gets the value of C<NID_mdc2>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_mdc2WithRSA

  static method NID_mdc2WithRSA : int ();

Gets the value of C<NID_mdc2WithRSA>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_ms_code_com

  static method NID_ms_code_com : int ();

Gets the value of C<NID_ms_code_com>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_ms_code_ind

  static method NID_ms_code_ind : int ();

Gets the value of C<NID_ms_code_ind>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_ms_ctl_sign

  static method NID_ms_ctl_sign : int ();

Gets the value of C<NID_ms_ctl_sign>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_ms_efs

  static method NID_ms_efs : int ();

Gets the value of C<NID_ms_efs>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_ms_ext_req

  static method NID_ms_ext_req : int ();

Gets the value of C<NID_ms_ext_req>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_ms_sgc

  static method NID_ms_sgc : int ();

Gets the value of C<NID_ms_sgc>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_name

  static method NID_name : int ();

Gets the value of C<NID_name>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_netscape

  static method NID_netscape : int ();

Gets the value of C<NID_netscape>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_netscape_base_url

  static method NID_netscape_base_url : int ();

Gets the value of C<NID_netscape_base_url>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_netscape_ca_policy_url

  static method NID_netscape_ca_policy_url : int ();

Gets the value of C<NID_netscape_ca_policy_url>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_netscape_ca_revocation_url

  static method NID_netscape_ca_revocation_url : int ();

Gets the value of C<NID_netscape_ca_revocation_url>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_netscape_cert_extension

  static method NID_netscape_cert_extension : int ();

Gets the value of C<NID_netscape_cert_extension>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_netscape_cert_sequence

  static method NID_netscape_cert_sequence : int ();

Gets the value of C<NID_netscape_cert_sequence>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_netscape_cert_type

  static method NID_netscape_cert_type : int ();

Gets the value of C<NID_netscape_cert_type>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_netscape_comment

  static method NID_netscape_comment : int ();

Gets the value of C<NID_netscape_comment>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_netscape_data_type

  static method NID_netscape_data_type : int ();

Gets the value of C<NID_netscape_data_type>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_netscape_renewal_url

  static method NID_netscape_renewal_url : int ();

Gets the value of C<NID_netscape_renewal_url>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_netscape_revocation_url

  static method NID_netscape_revocation_url : int ();

Gets the value of C<NID_netscape_revocation_url>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_netscape_ssl_server_name

  static method NID_netscape_ssl_server_name : int ();

Gets the value of C<NID_netscape_ssl_server_name>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_ns_sgc

  static method NID_ns_sgc : int ();

Gets the value of C<NID_ns_sgc>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_organizationName

  static method NID_organizationName : int ();

Gets the value of C<NID_organizationName>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_organizationalUnitName

  static method NID_organizationalUnitName : int ();

Gets the value of C<NID_organizationalUnitName>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pbeWithMD2AndDES_CBC

  static method NID_pbeWithMD2AndDES_CBC : int ();

Gets the value of C<NID_pbeWithMD2AndDES_CBC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pbeWithMD2AndRC2_CBC

  static method NID_pbeWithMD2AndRC2_CBC : int ();

Gets the value of C<NID_pbeWithMD2AndRC2_CBC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pbeWithMD5AndCast5_CBC

  static method NID_pbeWithMD5AndCast5_CBC : int ();

Gets the value of C<NID_pbeWithMD5AndCast5_CBC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pbeWithMD5AndDES_CBC

  static method NID_pbeWithMD5AndDES_CBC : int ();

Gets the value of C<NID_pbeWithMD5AndDES_CBC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pbeWithMD5AndRC2_CBC

  static method NID_pbeWithMD5AndRC2_CBC : int ();

Gets the value of C<NID_pbeWithMD5AndRC2_CBC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pbeWithSHA1AndDES_CBC

  static method NID_pbeWithSHA1AndDES_CBC : int ();

Gets the value of C<NID_pbeWithSHA1AndDES_CBC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pbeWithSHA1AndRC2_CBC

  static method NID_pbeWithSHA1AndRC2_CBC : int ();

Gets the value of C<NID_pbeWithSHA1AndRC2_CBC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pbe_WithSHA1And128BitRC2_CBC

  static method NID_pbe_WithSHA1And128BitRC2_CBC : int ();

Gets the value of C<NID_pbe_WithSHA1And128BitRC2_CBC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pbe_WithSHA1And128BitRC4

  static method NID_pbe_WithSHA1And128BitRC4 : int ();

Gets the value of C<NID_pbe_WithSHA1And128BitRC4>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pbe_WithSHA1And2_Key_TripleDES_CBC

  static method NID_pbe_WithSHA1And2_Key_TripleDES_CBC : int ();

Gets the value of C<NID_pbe_WithSHA1And2_Key_TripleDES_CBC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pbe_WithSHA1And3_Key_TripleDES_CBC

  static method NID_pbe_WithSHA1And3_Key_TripleDES_CBC : int ();

Gets the value of C<NID_pbe_WithSHA1And3_Key_TripleDES_CBC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pbe_WithSHA1And40BitRC2_CBC

  static method NID_pbe_WithSHA1And40BitRC2_CBC : int ();

Gets the value of C<NID_pbe_WithSHA1And40BitRC2_CBC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pbe_WithSHA1And40BitRC4

  static method NID_pbe_WithSHA1And40BitRC4 : int ();

Gets the value of C<NID_pbe_WithSHA1And40BitRC4>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pbes2

  static method NID_pbes2 : int ();

Gets the value of C<NID_pbes2>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pbmac1

  static method NID_pbmac1 : int ();

Gets the value of C<NID_pbmac1>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs

  static method NID_pkcs : int ();

Gets the value of C<NID_pkcs>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs3

  static method NID_pkcs3 : int ();

Gets the value of C<NID_pkcs3>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs7

  static method NID_pkcs7 : int ();

Gets the value of C<NID_pkcs7>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs7_data

  static method NID_pkcs7_data : int ();

Gets the value of C<NID_pkcs7_data>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs7_digest

  static method NID_pkcs7_digest : int ();

Gets the value of C<NID_pkcs7_digest>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs7_encrypted

  static method NID_pkcs7_encrypted : int ();

Gets the value of C<NID_pkcs7_encrypted>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs7_enveloped

  static method NID_pkcs7_enveloped : int ();

Gets the value of C<NID_pkcs7_enveloped>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs7_signed

  static method NID_pkcs7_signed : int ();

Gets the value of C<NID_pkcs7_signed>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs7_signedAndEnveloped

  static method NID_pkcs7_signedAndEnveloped : int ();

Gets the value of C<NID_pkcs7_signedAndEnveloped>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs8ShroudedKeyBag

  static method NID_pkcs8ShroudedKeyBag : int ();

Gets the value of C<NID_pkcs8ShroudedKeyBag>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs9

  static method NID_pkcs9 : int ();

Gets the value of C<NID_pkcs9>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs9_challengePassword

  static method NID_pkcs9_challengePassword : int ();

Gets the value of C<NID_pkcs9_challengePassword>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs9_contentType

  static method NID_pkcs9_contentType : int ();

Gets the value of C<NID_pkcs9_contentType>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs9_countersignature

  static method NID_pkcs9_countersignature : int ();

Gets the value of C<NID_pkcs9_countersignature>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs9_emailAddress

  static method NID_pkcs9_emailAddress : int ();

Gets the value of C<NID_pkcs9_emailAddress>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs9_extCertAttributes

  static method NID_pkcs9_extCertAttributes : int ();

Gets the value of C<NID_pkcs9_extCertAttributes>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs9_messageDigest

  static method NID_pkcs9_messageDigest : int ();

Gets the value of C<NID_pkcs9_messageDigest>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs9_signingTime

  static method NID_pkcs9_signingTime : int ();

Gets the value of C<NID_pkcs9_signingTime>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs9_unstructuredAddress

  static method NID_pkcs9_unstructuredAddress : int ();

Gets the value of C<NID_pkcs9_unstructuredAddress>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_pkcs9_unstructuredName

  static method NID_pkcs9_unstructuredName : int ();

Gets the value of C<NID_pkcs9_unstructuredName>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_private_key_usage_period

  static method NID_private_key_usage_period : int ();

Gets the value of C<NID_private_key_usage_period>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_rc2_40_cbc

  static method NID_rc2_40_cbc : int ();

Gets the value of C<NID_rc2_40_cbc>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_rc2_64_cbc

  static method NID_rc2_64_cbc : int ();

Gets the value of C<NID_rc2_64_cbc>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_rc2_cbc

  static method NID_rc2_cbc : int ();

Gets the value of C<NID_rc2_cbc>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_rc2_cfb64

  static method NID_rc2_cfb64 : int ();

Gets the value of C<NID_rc2_cfb64>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_rc2_ecb

  static method NID_rc2_ecb : int ();

Gets the value of C<NID_rc2_ecb>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_rc2_ofb64

  static method NID_rc2_ofb64 : int ();

Gets the value of C<NID_rc2_ofb64>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_rc4

  static method NID_rc4 : int ();

Gets the value of C<NID_rc4>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_rc4_40

  static method NID_rc4_40 : int ();

Gets the value of C<NID_rc4_40>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_rc5_cbc

  static method NID_rc5_cbc : int ();

Gets the value of C<NID_rc5_cbc>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_rc5_cfb64

  static method NID_rc5_cfb64 : int ();

Gets the value of C<NID_rc5_cfb64>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_rc5_ecb

  static method NID_rc5_ecb : int ();

Gets the value of C<NID_rc5_ecb>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_rc5_ofb64

  static method NID_rc5_ofb64 : int ();

Gets the value of C<NID_rc5_ofb64>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_ripemd160

  static method NID_ripemd160 : int ();

Gets the value of C<NID_ripemd160>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_ripemd160WithRSA

  static method NID_ripemd160WithRSA : int ();

Gets the value of C<NID_ripemd160WithRSA>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_rle_compression

  static method NID_rle_compression : int ();

Gets the value of C<NID_rle_compression>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_rsa

  static method NID_rsa : int ();

Gets the value of C<NID_rsa>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_rsaEncryption

  static method NID_rsaEncryption : int ();

Gets the value of C<NID_rsaEncryption>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_rsadsi

  static method NID_rsadsi : int ();

Gets the value of C<NID_rsadsi>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_safeContentsBag

  static method NID_safeContentsBag : int ();

Gets the value of C<NID_safeContentsBag>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_sdsiCertificate

  static method NID_sdsiCertificate : int ();

Gets the value of C<NID_sdsiCertificate>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_secretBag

  static method NID_secretBag : int ();

Gets the value of C<NID_secretBag>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_serialNumber

  static method NID_serialNumber : int ();

Gets the value of C<NID_serialNumber>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_server_auth

  static method NID_server_auth : int ();

Gets the value of C<NID_server_auth>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_sha

  static method NID_sha : int ();

Gets the value of C<NID_sha>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_sha1

  static method NID_sha1 : int ();

Gets the value of C<NID_sha1>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_sha1WithRSA

  static method NID_sha1WithRSA : int ();

Gets the value of C<NID_sha1WithRSA>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_sha1WithRSAEncryption

  static method NID_sha1WithRSAEncryption : int ();

Gets the value of C<NID_sha1WithRSAEncryption>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_shaWithRSAEncryption

  static method NID_shaWithRSAEncryption : int ();

Gets the value of C<NID_shaWithRSAEncryption>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_stateOrProvinceName

  static method NID_stateOrProvinceName : int ();

Gets the value of C<NID_stateOrProvinceName>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_subject_alt_name

  static method NID_subject_alt_name : int ();

Gets the value of C<NID_subject_alt_name>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_subject_key_identifier

  static method NID_subject_key_identifier : int ();

Gets the value of C<NID_subject_key_identifier>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_surname

  static method NID_surname : int ();

Gets the value of C<NID_surname>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_sxnet

  static method NID_sxnet : int ();

Gets the value of C<NID_sxnet>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_time_stamp

  static method NID_time_stamp : int ();

Gets the value of C<NID_time_stamp>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_title

  static method NID_title : int ();

Gets the value of C<NID_title>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_undef

  static method NID_undef : int ();

Gets the value of C<NID_undef>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_uniqueIdentifier

  static method NID_uniqueIdentifier : int ();

Gets the value of C<NID_uniqueIdentifier>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_x509Certificate

  static method NID_x509Certificate : int ();

Gets the value of C<NID_x509Certificate>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_x509Crl

  static method NID_x509Crl : int ();

Gets the value of C<NID_x509Crl>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 NID_zlib_compression

  static method NID_zlib_compression : int ();

Gets the value of C<NID_zlib_compression>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OCSP_RESPONSE_STATUS_INTERNALERROR

  static method OCSP_RESPONSE_STATUS_INTERNALERROR : int ();

Gets the value of C<OCSP_RESPONSE_STATUS_INTERNALERROR>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OCSP_RESPONSE_STATUS_MALFORMEDREQUEST

  static method OCSP_RESPONSE_STATUS_MALFORMEDREQUEST : int ();

Gets the value of C<OCSP_RESPONSE_STATUS_MALFORMEDREQUEST>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OCSP_RESPONSE_STATUS_SIGREQUIRED

  static method OCSP_RESPONSE_STATUS_SIGREQUIRED : int ();

Gets the value of C<OCSP_RESPONSE_STATUS_SIGREQUIRED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OCSP_RESPONSE_STATUS_SUCCESSFUL

  static method OCSP_RESPONSE_STATUS_SUCCESSFUL : int ();

Gets the value of C<OCSP_RESPONSE_STATUS_SUCCESSFUL>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OCSP_RESPONSE_STATUS_TRYLATER

  static method OCSP_RESPONSE_STATUS_TRYLATER : int ();

Gets the value of C<OCSP_RESPONSE_STATUS_TRYLATER>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OCSP_RESPONSE_STATUS_UNAUTHORIZED

  static method OCSP_RESPONSE_STATUS_UNAUTHORIZED : int ();

Gets the value of C<OCSP_RESPONSE_STATUS_UNAUTHORIZED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_BUILT_ON

  static method OPENSSL_BUILT_ON : int ();

Gets the value of C<OPENSSL_BUILT_ON>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_CFLAGS

  static method OPENSSL_CFLAGS : int ();

Gets the value of C<OPENSSL_CFLAGS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_CPU_INFO

  static method OPENSSL_CPU_INFO : int ();

Gets the value of C<OPENSSL_CPU_INFO>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_DIR

  static method OPENSSL_DIR : int ();

Gets the value of C<OPENSSL_DIR>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_ENGINES_DIR

  static method OPENSSL_ENGINES_DIR : int ();

Gets the value of C<OPENSSL_ENGINES_DIR>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_FULL_VERSION_STRING

  static method OPENSSL_FULL_VERSION_STRING : int ();

Gets the value of C<OPENSSL_FULL_VERSION_STRING>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_INFO_CONFIG_DIR

  static method OPENSSL_INFO_CONFIG_DIR : int ();

Gets the value of C<OPENSSL_INFO_CONFIG_DIR>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_INFO_CPU_SETTINGS

  static method OPENSSL_INFO_CPU_SETTINGS : int ();

Gets the value of C<OPENSSL_INFO_CPU_SETTINGS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_INFO_DIR_FILENAME_SEPARATOR

  static method OPENSSL_INFO_DIR_FILENAME_SEPARATOR : int ();

Gets the value of C<OPENSSL_INFO_DIR_FILENAME_SEPARATOR>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_INFO_DSO_EXTENSION

  static method OPENSSL_INFO_DSO_EXTENSION : int ();

Gets the value of C<OPENSSL_INFO_DSO_EXTENSION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_INFO_ENGINES_DIR

  static method OPENSSL_INFO_ENGINES_DIR : int ();

Gets the value of C<OPENSSL_INFO_ENGINES_DIR>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_INFO_LIST_SEPARATOR

  static method OPENSSL_INFO_LIST_SEPARATOR : int ();

Gets the value of C<OPENSSL_INFO_LIST_SEPARATOR>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_INFO_MODULES_DIR

  static method OPENSSL_INFO_MODULES_DIR : int ();

Gets the value of C<OPENSSL_INFO_MODULES_DIR>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_INFO_SEED_SOURCE

  static method OPENSSL_INFO_SEED_SOURCE : int ();

Gets the value of C<OPENSSL_INFO_SEED_SOURCE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_MODULES_DIR

  static method OPENSSL_MODULES_DIR : int ();

Gets the value of C<OPENSSL_MODULES_DIR>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_PLATFORM

  static method OPENSSL_PLATFORM : int ();

Gets the value of C<OPENSSL_PLATFORM>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_VERSION

  static method OPENSSL_VERSION : int ();

Gets the value of C<OPENSSL_VERSION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_VERSION_MAJOR

  static method OPENSSL_VERSION_MAJOR : int ();

Gets the value of C<OPENSSL_VERSION_MAJOR>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_VERSION_MINOR

  static method OPENSSL_VERSION_MINOR : int ();

Gets the value of C<OPENSSL_VERSION_MINOR>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_VERSION_NUMBER

  static method OPENSSL_VERSION_NUMBER : int ();

Gets the value of C<OPENSSL_VERSION_NUMBER>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_VERSION_PATCH

  static method OPENSSL_VERSION_PATCH : int ();

Gets the value of C<OPENSSL_VERSION_PATCH>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OPENSSL_VERSION_STRING

  static method OPENSSL_VERSION_STRING : int ();

Gets the value of C<OPENSSL_VERSION_STRING>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 RSA_3

  static method RSA_3 : int ();

Gets the value of C<RSA_3>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 RSA_F4

  static method RSA_F4 : int ();

Gets the value of C<RSA_F4>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL2_MT_CLIENT_CERTIFICATE

  static method SSL2_MT_CLIENT_CERTIFICATE : int ();

Gets the value of C<SSL2_MT_CLIENT_CERTIFICATE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL2_MT_CLIENT_FINISHED

  static method SSL2_MT_CLIENT_FINISHED : int ();

Gets the value of C<SSL2_MT_CLIENT_FINISHED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL2_MT_CLIENT_HELLO

  static method SSL2_MT_CLIENT_HELLO : int ();

Gets the value of C<SSL2_MT_CLIENT_HELLO>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL2_MT_CLIENT_MASTER_KEY

  static method SSL2_MT_CLIENT_MASTER_KEY : int ();

Gets the value of C<SSL2_MT_CLIENT_MASTER_KEY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL2_MT_ERROR

  static method SSL2_MT_ERROR : int ();

Gets the value of C<SSL2_MT_ERROR>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL2_MT_REQUEST_CERTIFICATE

  static method SSL2_MT_REQUEST_CERTIFICATE : int ();

Gets the value of C<SSL2_MT_REQUEST_CERTIFICATE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL2_MT_SERVER_FINISHED

  static method SSL2_MT_SERVER_FINISHED : int ();

Gets the value of C<SSL2_MT_SERVER_FINISHED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL2_MT_SERVER_HELLO

  static method SSL2_MT_SERVER_HELLO : int ();

Gets the value of C<SSL2_MT_SERVER_HELLO>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL2_MT_SERVER_VERIFY

  static method SSL2_MT_SERVER_VERIFY : int ();

Gets the value of C<SSL2_MT_SERVER_VERIFY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL2_VERSION

  static method SSL2_VERSION : int ();

Gets the value of C<SSL2_VERSION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_CCS

  static method SSL3_MT_CCS : int ();

Gets the value of C<SSL3_MT_CCS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_CERTIFICATE

  static method SSL3_MT_CERTIFICATE : int ();

Gets the value of C<SSL3_MT_CERTIFICATE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_CERTIFICATE_REQUEST

  static method SSL3_MT_CERTIFICATE_REQUEST : int ();

Gets the value of C<SSL3_MT_CERTIFICATE_REQUEST>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_CERTIFICATE_STATUS

  static method SSL3_MT_CERTIFICATE_STATUS : int ();

Gets the value of C<SSL3_MT_CERTIFICATE_STATUS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_CERTIFICATE_URL

  static method SSL3_MT_CERTIFICATE_URL : int ();

Gets the value of C<SSL3_MT_CERTIFICATE_URL>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_CERTIFICATE_VERIFY

  static method SSL3_MT_CERTIFICATE_VERIFY : int ();

Gets the value of C<SSL3_MT_CERTIFICATE_VERIFY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_CHANGE_CIPHER_SPEC

  static method SSL3_MT_CHANGE_CIPHER_SPEC : int ();

Gets the value of C<SSL3_MT_CHANGE_CIPHER_SPEC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_CLIENT_HELLO

  static method SSL3_MT_CLIENT_HELLO : int ();

Gets the value of C<SSL3_MT_CLIENT_HELLO>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_CLIENT_KEY_EXCHANGE

  static method SSL3_MT_CLIENT_KEY_EXCHANGE : int ();

Gets the value of C<SSL3_MT_CLIENT_KEY_EXCHANGE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_ENCRYPTED_EXTENSIONS

  static method SSL3_MT_ENCRYPTED_EXTENSIONS : int ();

Gets the value of C<SSL3_MT_ENCRYPTED_EXTENSIONS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_END_OF_EARLY_DATA

  static method SSL3_MT_END_OF_EARLY_DATA : int ();

Gets the value of C<SSL3_MT_END_OF_EARLY_DATA>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_FINISHED

  static method SSL3_MT_FINISHED : int ();

Gets the value of C<SSL3_MT_FINISHED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_HELLO_REQUEST

  static method SSL3_MT_HELLO_REQUEST : int ();

Gets the value of C<SSL3_MT_HELLO_REQUEST>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_KEY_UPDATE

  static method SSL3_MT_KEY_UPDATE : int ();

Gets the value of C<SSL3_MT_KEY_UPDATE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_MESSAGE_HASH

  static method SSL3_MT_MESSAGE_HASH : int ();

Gets the value of C<SSL3_MT_MESSAGE_HASH>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_NEWSESSION_TICKET

  static method SSL3_MT_NEWSESSION_TICKET : int ();

Gets the value of C<SSL3_MT_NEWSESSION_TICKET>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_NEXT_PROTO

  static method SSL3_MT_NEXT_PROTO : int ();

Gets the value of C<SSL3_MT_NEXT_PROTO>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_SERVER_DONE

  static method SSL3_MT_SERVER_DONE : int ();

Gets the value of C<SSL3_MT_SERVER_DONE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_SERVER_HELLO

  static method SSL3_MT_SERVER_HELLO : int ();

Gets the value of C<SSL3_MT_SERVER_HELLO>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_SERVER_KEY_EXCHANGE

  static method SSL3_MT_SERVER_KEY_EXCHANGE : int ();

Gets the value of C<SSL3_MT_SERVER_KEY_EXCHANGE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_MT_SUPPLEMENTAL_DATA

  static method SSL3_MT_SUPPLEMENTAL_DATA : int ();

Gets the value of C<SSL3_MT_SUPPLEMENTAL_DATA>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_RT_ALERT

  static method SSL3_RT_ALERT : int ();

Gets the value of C<SSL3_RT_ALERT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_RT_APPLICATION_DATA

  static method SSL3_RT_APPLICATION_DATA : int ();

Gets the value of C<SSL3_RT_APPLICATION_DATA>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_RT_CHANGE_CIPHER_SPEC

  static method SSL3_RT_CHANGE_CIPHER_SPEC : int ();

Gets the value of C<SSL3_RT_CHANGE_CIPHER_SPEC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_RT_HANDSHAKE

  static method SSL3_RT_HANDSHAKE : int ();

Gets the value of C<SSL3_RT_HANDSHAKE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_RT_HEADER

  static method SSL3_RT_HEADER : int ();

Gets the value of C<SSL3_RT_HEADER>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_RT_INNER_CONTENT_TYPE

  static method SSL3_RT_INNER_CONTENT_TYPE : int ();

Gets the value of C<SSL3_RT_INNER_CONTENT_TYPE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL3_VERSION

  static method SSL3_VERSION : int ();

Gets the value of C<SSL3_VERSION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSLEAY_BUILT_ON

  static method SSLEAY_BUILT_ON : int ();

Gets the value of C<SSLEAY_BUILT_ON>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSLEAY_CFLAGS

  static method SSLEAY_CFLAGS : int ();

Gets the value of C<SSLEAY_CFLAGS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSLEAY_DIR

  static method SSLEAY_DIR : int ();

Gets the value of C<SSLEAY_DIR>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSLEAY_PLATFORM

  static method SSLEAY_PLATFORM : int ();

Gets the value of C<SSLEAY_PLATFORM>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSLEAY_VERSION

  static method SSLEAY_VERSION : int ();

Gets the value of C<SSLEAY_VERSION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_CB_ACCEPT_EXIT

  static method SSL_CB_ACCEPT_EXIT : int ();

Gets the value of C<SSL_CB_ACCEPT_EXIT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_CB_ACCEPT_LOOP

  static method SSL_CB_ACCEPT_LOOP : int ();

Gets the value of C<SSL_CB_ACCEPT_LOOP>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_CB_ALERT

  static method SSL_CB_ALERT : int ();

Gets the value of C<SSL_CB_ALERT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_CB_CONNECT_EXIT

  static method SSL_CB_CONNECT_EXIT : int ();

Gets the value of C<SSL_CB_CONNECT_EXIT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_CB_CONNECT_LOOP

  static method SSL_CB_CONNECT_LOOP : int ();

Gets the value of C<SSL_CB_CONNECT_LOOP>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_CB_EXIT

  static method SSL_CB_EXIT : int ();

Gets the value of C<SSL_CB_EXIT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_CB_HANDSHAKE_DONE

  static method SSL_CB_HANDSHAKE_DONE : int ();

Gets the value of C<SSL_CB_HANDSHAKE_DONE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_CB_HANDSHAKE_START

  static method SSL_CB_HANDSHAKE_START : int ();

Gets the value of C<SSL_CB_HANDSHAKE_START>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_CB_LOOP

  static method SSL_CB_LOOP : int ();

Gets the value of C<SSL_CB_LOOP>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_CB_READ

  static method SSL_CB_READ : int ();

Gets the value of C<SSL_CB_READ>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_CB_READ_ALERT

  static method SSL_CB_READ_ALERT : int ();

Gets the value of C<SSL_CB_READ_ALERT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_CB_WRITE

  static method SSL_CB_WRITE : int ();

Gets the value of C<SSL_CB_WRITE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_CB_WRITE_ALERT

  static method SSL_CB_WRITE_ALERT : int ();

Gets the value of C<SSL_CB_WRITE_ALERT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_ERROR_NONE

  static method SSL_ERROR_NONE : int ();

Gets the value of C<SSL_ERROR_NONE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_ERROR_SSL

  static method SSL_ERROR_SSL : int ();

Gets the value of C<SSL_ERROR_SSL>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_ERROR_SYSCALL

  static method SSL_ERROR_SYSCALL : int ();

Gets the value of C<SSL_ERROR_SYSCALL>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_ERROR_WANT_ACCEPT

  static method SSL_ERROR_WANT_ACCEPT : int ();

Gets the value of C<SSL_ERROR_WANT_ACCEPT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_ERROR_WANT_CONNECT

  static method SSL_ERROR_WANT_CONNECT : int ();

Gets the value of C<SSL_ERROR_WANT_CONNECT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_ERROR_WANT_READ

  static method SSL_ERROR_WANT_READ : int ();

Gets the value of C<SSL_ERROR_WANT_READ>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_ERROR_WANT_WRITE

  static method SSL_ERROR_WANT_WRITE : int ();

Gets the value of C<SSL_ERROR_WANT_WRITE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_ERROR_WANT_X509_LOOKUP

  static method SSL_ERROR_WANT_X509_LOOKUP : int ();

Gets the value of C<SSL_ERROR_WANT_X509_LOOKUP>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_ERROR_ZERO_RETURN

  static method SSL_ERROR_ZERO_RETURN : int ();

Gets the value of C<SSL_ERROR_ZERO_RETURN>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_FILETYPE_ASN1

  static method SSL_FILETYPE_ASN1 : int ();

Gets the value of C<SSL_FILETYPE_ASN1>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_FILETYPE_PEM

  static method SSL_FILETYPE_PEM : int ();

Gets the value of C<SSL_FILETYPE_PEM>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_CLIENT_CERTIFICATE

  static method SSL_F_CLIENT_CERTIFICATE : int ();

Gets the value of C<SSL_F_CLIENT_CERTIFICATE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_CLIENT_HELLO

  static method SSL_F_CLIENT_HELLO : int ();

Gets the value of C<SSL_F_CLIENT_HELLO>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_CLIENT_MASTER_KEY

  static method SSL_F_CLIENT_MASTER_KEY : int ();

Gets the value of C<SSL_F_CLIENT_MASTER_KEY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_D2I_SSL_SESSION

  static method SSL_F_D2I_SSL_SESSION : int ();

Gets the value of C<SSL_F_D2I_SSL_SESSION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_GET_CLIENT_FINISHED

  static method SSL_F_GET_CLIENT_FINISHED : int ();

Gets the value of C<SSL_F_GET_CLIENT_FINISHED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_GET_CLIENT_HELLO

  static method SSL_F_GET_CLIENT_HELLO : int ();

Gets the value of C<SSL_F_GET_CLIENT_HELLO>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_GET_CLIENT_MASTER_KEY

  static method SSL_F_GET_CLIENT_MASTER_KEY : int ();

Gets the value of C<SSL_F_GET_CLIENT_MASTER_KEY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_GET_SERVER_FINISHED

  static method SSL_F_GET_SERVER_FINISHED : int ();

Gets the value of C<SSL_F_GET_SERVER_FINISHED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_GET_SERVER_HELLO

  static method SSL_F_GET_SERVER_HELLO : int ();

Gets the value of C<SSL_F_GET_SERVER_HELLO>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_GET_SERVER_VERIFY

  static method SSL_F_GET_SERVER_VERIFY : int ();

Gets the value of C<SSL_F_GET_SERVER_VERIFY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_I2D_SSL_SESSION

  static method SSL_F_I2D_SSL_SESSION : int ();

Gets the value of C<SSL_F_I2D_SSL_SESSION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_READ_N

  static method SSL_F_READ_N : int ();

Gets the value of C<SSL_F_READ_N>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_REQUEST_CERTIFICATE

  static method SSL_F_REQUEST_CERTIFICATE : int ();

Gets the value of C<SSL_F_REQUEST_CERTIFICATE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SERVER_HELLO

  static method SSL_F_SERVER_HELLO : int ();

Gets the value of C<SSL_F_SERVER_HELLO>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_CERT_NEW

  static method SSL_F_SSL_CERT_NEW : int ();

Gets the value of C<SSL_F_SSL_CERT_NEW>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_GET_NEW_SESSION

  static method SSL_F_SSL_GET_NEW_SESSION : int ();

Gets the value of C<SSL_F_SSL_GET_NEW_SESSION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_NEW

  static method SSL_F_SSL_NEW : int ();

Gets the value of C<SSL_F_SSL_NEW>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_READ

  static method SSL_F_SSL_READ : int ();

Gets the value of C<SSL_F_SSL_READ>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_RSA_PRIVATE_DECRYPT

  static method SSL_F_SSL_RSA_PRIVATE_DECRYPT : int ();

Gets the value of C<SSL_F_SSL_RSA_PRIVATE_DECRYPT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_RSA_PUBLIC_ENCRYPT

  static method SSL_F_SSL_RSA_PUBLIC_ENCRYPT : int ();

Gets the value of C<SSL_F_SSL_RSA_PUBLIC_ENCRYPT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_SESSION_NEW

  static method SSL_F_SSL_SESSION_NEW : int ();

Gets the value of C<SSL_F_SSL_SESSION_NEW>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_SESSION_PRINT_FP

  static method SSL_F_SSL_SESSION_PRINT_FP : int ();

Gets the value of C<SSL_F_SSL_SESSION_PRINT_FP>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_SET_FD

  static method SSL_F_SSL_SET_FD : int ();

Gets the value of C<SSL_F_SSL_SET_FD>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_SET_RFD

  static method SSL_F_SSL_SET_RFD : int ();

Gets the value of C<SSL_F_SSL_SET_RFD>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_SET_WFD

  static method SSL_F_SSL_SET_WFD : int ();

Gets the value of C<SSL_F_SSL_SET_WFD>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_USE_CERTIFICATE

  static method SSL_F_SSL_USE_CERTIFICATE : int ();

Gets the value of C<SSL_F_SSL_USE_CERTIFICATE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_USE_CERTIFICATE_ASN1

  static method SSL_F_SSL_USE_CERTIFICATE_ASN1 : int ();

Gets the value of C<SSL_F_SSL_USE_CERTIFICATE_ASN1>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_USE_CERTIFICATE_FILE

  static method SSL_F_SSL_USE_CERTIFICATE_FILE : int ();

Gets the value of C<SSL_F_SSL_USE_CERTIFICATE_FILE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_USE_PRIVATEKEY

  static method SSL_F_SSL_USE_PRIVATEKEY : int ();

Gets the value of C<SSL_F_SSL_USE_PRIVATEKEY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_USE_PRIVATEKEY_ASN1

  static method SSL_F_SSL_USE_PRIVATEKEY_ASN1 : int ();

Gets the value of C<SSL_F_SSL_USE_PRIVATEKEY_ASN1>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_USE_PRIVATEKEY_FILE

  static method SSL_F_SSL_USE_PRIVATEKEY_FILE : int ();

Gets the value of C<SSL_F_SSL_USE_PRIVATEKEY_FILE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_USE_RSAPRIVATEKEY

  static method SSL_F_SSL_USE_RSAPRIVATEKEY : int ();

Gets the value of C<SSL_F_SSL_USE_RSAPRIVATEKEY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_USE_RSAPRIVATEKEY_ASN1

  static method SSL_F_SSL_USE_RSAPRIVATEKEY_ASN1 : int ();

Gets the value of C<SSL_F_SSL_USE_RSAPRIVATEKEY_ASN1>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_SSL_USE_RSAPRIVATEKEY_FILE

  static method SSL_F_SSL_USE_RSAPRIVATEKEY_FILE : int ();

Gets the value of C<SSL_F_SSL_USE_RSAPRIVATEKEY_FILE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_F_WRITE_PENDING

  static method SSL_F_WRITE_PENDING : int ();

Gets the value of C<SSL_F_WRITE_PENDING>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_MIN_RSA_MODULUS_LENGTH_IN_BYTES

  static method SSL_MIN_RSA_MODULUS_LENGTH_IN_BYTES : int ();

Gets the value of C<SSL_MIN_RSA_MODULUS_LENGTH_IN_BYTES>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER

  static method SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER : int ();

Gets the value of C<SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_MODE_AUTO_RETRY

  static method SSL_MODE_AUTO_RETRY : int ();

Gets the value of C<SSL_MODE_AUTO_RETRY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_MODE_ENABLE_PARTIAL_WRITE

  static method SSL_MODE_ENABLE_PARTIAL_WRITE : int ();

Gets the value of C<SSL_MODE_ENABLE_PARTIAL_WRITE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_MODE_RELEASE_BUFFERS

  static method SSL_MODE_RELEASE_BUFFERS : int ();

Gets the value of C<SSL_MODE_RELEASE_BUFFERS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_NOTHING

  static method SSL_NOTHING : int ();

Gets the value of C<SSL_NOTHING>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_ALL

  static method SSL_OP_ALL : int ();

Gets the value of C<SSL_OP_ALL>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_ALLOW_NO_DHE_KEX

  static method SSL_OP_ALLOW_NO_DHE_KEX : int ();

Gets the value of C<SSL_OP_ALLOW_NO_DHE_KEX>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION

  static method SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION : int ();

Gets the value of C<SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_CIPHER_SERVER_PREFERENCE

  static method SSL_OP_CIPHER_SERVER_PREFERENCE : int ();

Gets the value of C<SSL_OP_CIPHER_SERVER_PREFERENCE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_CISCO_ANYCONNECT

  static method SSL_OP_CISCO_ANYCONNECT : int ();

Gets the value of C<SSL_OP_CISCO_ANYCONNECT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_COOKIE_EXCHANGE

  static method SSL_OP_COOKIE_EXCHANGE : int ();

Gets the value of C<SSL_OP_COOKIE_EXCHANGE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_CRYPTOPRO_TLSEXT_BUG

  static method SSL_OP_CRYPTOPRO_TLSEXT_BUG : int ();

Gets the value of C<SSL_OP_CRYPTOPRO_TLSEXT_BUG>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS

  static method SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS : int ();

Gets the value of C<SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_ENABLE_MIDDLEBOX_COMPAT

  static method SSL_OP_ENABLE_MIDDLEBOX_COMPAT : int ();

Gets the value of C<SSL_OP_ENABLE_MIDDLEBOX_COMPAT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_EPHEMERAL_RSA

  static method SSL_OP_EPHEMERAL_RSA : int ();

Gets the value of C<SSL_OP_EPHEMERAL_RSA>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_LEGACY_SERVER_CONNECT

  static method SSL_OP_LEGACY_SERVER_CONNECT : int ();

Gets the value of C<SSL_OP_LEGACY_SERVER_CONNECT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_MICROSOFT_BIG_SSLV3_BUFFER

  static method SSL_OP_MICROSOFT_BIG_SSLV3_BUFFER : int ();

Gets the value of C<SSL_OP_MICROSOFT_BIG_SSLV3_BUFFER>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_MICROSOFT_SESS_ID_BUG

  static method SSL_OP_MICROSOFT_SESS_ID_BUG : int ();

Gets the value of C<SSL_OP_MICROSOFT_SESS_ID_BUG>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_MSIE_SSLV2_RSA_PADDING

  static method SSL_OP_MSIE_SSLV2_RSA_PADDING : int ();

Gets the value of C<SSL_OP_MSIE_SSLV2_RSA_PADDING>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NETSCAPE_CA_DN_BUG

  static method SSL_OP_NETSCAPE_CA_DN_BUG : int ();

Gets the value of C<SSL_OP_NETSCAPE_CA_DN_BUG>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NETSCAPE_CHALLENGE_BUG

  static method SSL_OP_NETSCAPE_CHALLENGE_BUG : int ();

Gets the value of C<SSL_OP_NETSCAPE_CHALLENGE_BUG>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NETSCAPE_DEMO_CIPHER_CHANGE_BUG

  static method SSL_OP_NETSCAPE_DEMO_CIPHER_CHANGE_BUG : int ();

Gets the value of C<SSL_OP_NETSCAPE_DEMO_CIPHER_CHANGE_BUG>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NETSCAPE_REUSE_CIPHER_CHANGE_BUG

  static method SSL_OP_NETSCAPE_REUSE_CIPHER_CHANGE_BUG : int ();

Gets the value of C<SSL_OP_NETSCAPE_REUSE_CIPHER_CHANGE_BUG>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NON_EXPORT_FIRST

  static method SSL_OP_NON_EXPORT_FIRST : int ();

Gets the value of C<SSL_OP_NON_EXPORT_FIRST>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NO_ANTI_REPLAY

  static method SSL_OP_NO_ANTI_REPLAY : int ();

Gets the value of C<SSL_OP_NO_ANTI_REPLAY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NO_CLIENT_RENEGOTIATION

  static method SSL_OP_NO_CLIENT_RENEGOTIATION : int ();

Gets the value of C<SSL_OP_NO_CLIENT_RENEGOTIATION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NO_COMPRESSION

  static method SSL_OP_NO_COMPRESSION : int ();

Gets the value of C<SSL_OP_NO_COMPRESSION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NO_ENCRYPT_THEN_MAC

  static method SSL_OP_NO_ENCRYPT_THEN_MAC : int ();

Gets the value of C<SSL_OP_NO_ENCRYPT_THEN_MAC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NO_QUERY_MTU

  static method SSL_OP_NO_QUERY_MTU : int ();

Gets the value of C<SSL_OP_NO_QUERY_MTU>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NO_RENEGOTIATION

  static method SSL_OP_NO_RENEGOTIATION : int ();

Gets the value of C<SSL_OP_NO_RENEGOTIATION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NO_SESSION_RESUMPTION_ON_RENEGOTIATION

  static method SSL_OP_NO_SESSION_RESUMPTION_ON_RENEGOTIATION : int ();

Gets the value of C<SSL_OP_NO_SESSION_RESUMPTION_ON_RENEGOTIATION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NO_SSL_MASK

  static method SSL_OP_NO_SSL_MASK : int ();

Gets the value of C<SSL_OP_NO_SSL_MASK>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NO_SSLv2

  static method SSL_OP_NO_SSLv2 : int ();

Gets the value of C<SSL_OP_NO_SSLv2>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NO_SSLv3

  static method SSL_OP_NO_SSLv3 : int ();

Gets the value of C<SSL_OP_NO_SSLv3>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NO_TICKET

  static method SSL_OP_NO_TICKET : int ();

Gets the value of C<SSL_OP_NO_TICKET>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NO_TLSv1

  static method SSL_OP_NO_TLSv1 : int ();

Gets the value of C<SSL_OP_NO_TLSv1>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NO_TLSv1_1

  static method SSL_OP_NO_TLSv1_1 : int ();

Gets the value of C<SSL_OP_NO_TLSv1_1>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NO_TLSv1_2

  static method SSL_OP_NO_TLSv1_2 : int ();

Gets the value of C<SSL_OP_NO_TLSv1_2>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_NO_TLSv1_3

  static method SSL_OP_NO_TLSv1_3 : int ();

Gets the value of C<SSL_OP_NO_TLSv1_3>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_PKCS1_CHECK_1

  static method SSL_OP_PKCS1_CHECK_1 : int ();

Gets the value of C<SSL_OP_PKCS1_CHECK_1>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_PKCS1_CHECK_2

  static method SSL_OP_PKCS1_CHECK_2 : int ();

Gets the value of C<SSL_OP_PKCS1_CHECK_2>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_PRIORITIZE_CHACHA

  static method SSL_OP_PRIORITIZE_CHACHA : int ();

Gets the value of C<SSL_OP_PRIORITIZE_CHACHA>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_SAFARI_ECDHE_ECDSA_BUG

  static method SSL_OP_SAFARI_ECDHE_ECDSA_BUG : int ();

Gets the value of C<SSL_OP_SAFARI_ECDHE_ECDSA_BUG>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_SINGLE_DH_USE

  static method SSL_OP_SINGLE_DH_USE : int ();

Gets the value of C<SSL_OP_SINGLE_DH_USE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_SINGLE_ECDH_USE

  static method SSL_OP_SINGLE_ECDH_USE : int ();

Gets the value of C<SSL_OP_SINGLE_ECDH_USE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_SSLEAY_080_CLIENT_DH_BUG

  static method SSL_OP_SSLEAY_080_CLIENT_DH_BUG : int ();

Gets the value of C<SSL_OP_SSLEAY_080_CLIENT_DH_BUG>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_SSLREF2_REUSE_CERT_TYPE_BUG

  static method SSL_OP_SSLREF2_REUSE_CERT_TYPE_BUG : int ();

Gets the value of C<SSL_OP_SSLREF2_REUSE_CERT_TYPE_BUG>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_TLSEXT_PADDING

  static method SSL_OP_TLSEXT_PADDING : int ();

Gets the value of C<SSL_OP_TLSEXT_PADDING>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_TLS_BLOCK_PADDING_BUG

  static method SSL_OP_TLS_BLOCK_PADDING_BUG : int ();

Gets the value of C<SSL_OP_TLS_BLOCK_PADDING_BUG>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_TLS_D5_BUG

  static method SSL_OP_TLS_D5_BUG : int ();

Gets the value of C<SSL_OP_TLS_D5_BUG>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_OP_TLS_ROLLBACK_BUG

  static method SSL_OP_TLS_ROLLBACK_BUG : int ();

Gets the value of C<SSL_OP_TLS_ROLLBACK_BUG>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_READING

  static method SSL_READING : int ();

Gets the value of C<SSL_READING>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_RECEIVED_SHUTDOWN

  static method SSL_RECEIVED_SHUTDOWN : int ();

Gets the value of C<SSL_RECEIVED_SHUTDOWN>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_BAD_AUTHENTICATION_TYPE

  static method SSL_R_BAD_AUTHENTICATION_TYPE : int ();

Gets the value of C<SSL_R_BAD_AUTHENTICATION_TYPE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_BAD_CHECKSUM

  static method SSL_R_BAD_CHECKSUM : int ();

Gets the value of C<SSL_R_BAD_CHECKSUM>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_BAD_MAC_DECODE

  static method SSL_R_BAD_MAC_DECODE : int ();

Gets the value of C<SSL_R_BAD_MAC_DECODE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_BAD_RESPONSE_ARGUMENT

  static method SSL_R_BAD_RESPONSE_ARGUMENT : int ();

Gets the value of C<SSL_R_BAD_RESPONSE_ARGUMENT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_BAD_SSL_FILETYPE

  static method SSL_R_BAD_SSL_FILETYPE : int ();

Gets the value of C<SSL_R_BAD_SSL_FILETYPE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_BAD_SSL_SESSION_ID_LENGTH

  static method SSL_R_BAD_SSL_SESSION_ID_LENGTH : int ();

Gets the value of C<SSL_R_BAD_SSL_SESSION_ID_LENGTH>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_BAD_STATE

  static method SSL_R_BAD_STATE : int ();

Gets the value of C<SSL_R_BAD_STATE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_BAD_WRITE_RETRY

  static method SSL_R_BAD_WRITE_RETRY : int ();

Gets the value of C<SSL_R_BAD_WRITE_RETRY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_CHALLENGE_IS_DIFFERENT

  static method SSL_R_CHALLENGE_IS_DIFFERENT : int ();

Gets the value of C<SSL_R_CHALLENGE_IS_DIFFERENT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_CIPHER_TABLE_SRC_ERROR

  static method SSL_R_CIPHER_TABLE_SRC_ERROR : int ();

Gets the value of C<SSL_R_CIPHER_TABLE_SRC_ERROR>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_INVALID_CHALLENGE_LENGTH

  static method SSL_R_INVALID_CHALLENGE_LENGTH : int ();

Gets the value of C<SSL_R_INVALID_CHALLENGE_LENGTH>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_NO_CERTIFICATE_SET

  static method SSL_R_NO_CERTIFICATE_SET : int ();

Gets the value of C<SSL_R_NO_CERTIFICATE_SET>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_NO_CERTIFICATE_SPECIFIED

  static method SSL_R_NO_CERTIFICATE_SPECIFIED : int ();

Gets the value of C<SSL_R_NO_CERTIFICATE_SPECIFIED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_NO_CIPHER_LIST

  static method SSL_R_NO_CIPHER_LIST : int ();

Gets the value of C<SSL_R_NO_CIPHER_LIST>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_NO_CIPHER_MATCH

  static method SSL_R_NO_CIPHER_MATCH : int ();

Gets the value of C<SSL_R_NO_CIPHER_MATCH>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_NO_PRIVATEKEY

  static method SSL_R_NO_PRIVATEKEY : int ();

Gets the value of C<SSL_R_NO_PRIVATEKEY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_NO_PUBLICKEY

  static method SSL_R_NO_PUBLICKEY : int ();

Gets the value of C<SSL_R_NO_PUBLICKEY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_NULL_SSL_CTX

  static method SSL_R_NULL_SSL_CTX : int ();

Gets the value of C<SSL_R_NULL_SSL_CTX>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_PEER_DID_NOT_RETURN_A_CERTIFICATE

  static method SSL_R_PEER_DID_NOT_RETURN_A_CERTIFICATE : int ();

Gets the value of C<SSL_R_PEER_DID_NOT_RETURN_A_CERTIFICATE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_PEER_ERROR

  static method SSL_R_PEER_ERROR : int ();

Gets the value of C<SSL_R_PEER_ERROR>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_PEER_ERROR_CERTIFICATE

  static method SSL_R_PEER_ERROR_CERTIFICATE : int ();

Gets the value of C<SSL_R_PEER_ERROR_CERTIFICATE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_PEER_ERROR_NO_CIPHER

  static method SSL_R_PEER_ERROR_NO_CIPHER : int ();

Gets the value of C<SSL_R_PEER_ERROR_NO_CIPHER>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_PEER_ERROR_UNSUPPORTED_CERTIFICATE_TYPE

  static method SSL_R_PEER_ERROR_UNSUPPORTED_CERTIFICATE_TYPE : int ();

Gets the value of C<SSL_R_PEER_ERROR_UNSUPPORTED_CERTIFICATE_TYPE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_PUBLIC_KEY_ENCRYPT_ERROR

  static method SSL_R_PUBLIC_KEY_ENCRYPT_ERROR : int ();

Gets the value of C<SSL_R_PUBLIC_KEY_ENCRYPT_ERROR>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_PUBLIC_KEY_IS_NOT_RSA

  static method SSL_R_PUBLIC_KEY_IS_NOT_RSA : int ();

Gets the value of C<SSL_R_PUBLIC_KEY_IS_NOT_RSA>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_READ_WRONG_PACKET_TYPE

  static method SSL_R_READ_WRONG_PACKET_TYPE : int ();

Gets the value of C<SSL_R_READ_WRONG_PACKET_TYPE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_SHORT_READ

  static method SSL_R_SHORT_READ : int ();

Gets the value of C<SSL_R_SHORT_READ>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_SSL_SESSION_ID_IS_DIFFERENT

  static method SSL_R_SSL_SESSION_ID_IS_DIFFERENT : int ();

Gets the value of C<SSL_R_SSL_SESSION_ID_IS_DIFFERENT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_UNABLE_TO_EXTRACT_PUBLIC_KEY

  static method SSL_R_UNABLE_TO_EXTRACT_PUBLIC_KEY : int ();

Gets the value of C<SSL_R_UNABLE_TO_EXTRACT_PUBLIC_KEY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_UNKNOWN_REMOTE_ERROR_TYPE

  static method SSL_R_UNKNOWN_REMOTE_ERROR_TYPE : int ();

Gets the value of C<SSL_R_UNKNOWN_REMOTE_ERROR_TYPE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_UNKNOWN_STATE

  static method SSL_R_UNKNOWN_STATE : int ();

Gets the value of C<SSL_R_UNKNOWN_STATE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_R_X509_LIB

  static method SSL_R_X509_LIB : int ();

Gets the value of C<SSL_R_X509_LIB>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_SENT_SHUTDOWN

  static method SSL_SENT_SHUTDOWN : int ();

Gets the value of C<SSL_SENT_SHUTDOWN>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_SESSION_ASN1_VERSION

  static method SSL_SESSION_ASN1_VERSION : int ();

Gets the value of C<SSL_SESSION_ASN1_VERSION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_SESS_CACHE_BOTH

  static method SSL_SESS_CACHE_BOTH : int ();

Gets the value of C<SSL_SESS_CACHE_BOTH>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_SESS_CACHE_CLIENT

  static method SSL_SESS_CACHE_CLIENT : int ();

Gets the value of C<SSL_SESS_CACHE_CLIENT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_SESS_CACHE_NO_AUTO_CLEAR

  static method SSL_SESS_CACHE_NO_AUTO_CLEAR : int ();

Gets the value of C<SSL_SESS_CACHE_NO_AUTO_CLEAR>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_SESS_CACHE_NO_INTERNAL

  static method SSL_SESS_CACHE_NO_INTERNAL : int ();

Gets the value of C<SSL_SESS_CACHE_NO_INTERNAL>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_SESS_CACHE_NO_INTERNAL_LOOKUP

  static method SSL_SESS_CACHE_NO_INTERNAL_LOOKUP : int ();

Gets the value of C<SSL_SESS_CACHE_NO_INTERNAL_LOOKUP>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_SESS_CACHE_NO_INTERNAL_STORE

  static method SSL_SESS_CACHE_NO_INTERNAL_STORE : int ();

Gets the value of C<SSL_SESS_CACHE_NO_INTERNAL_STORE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_SESS_CACHE_OFF

  static method SSL_SESS_CACHE_OFF : int ();

Gets the value of C<SSL_SESS_CACHE_OFF>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_SESS_CACHE_SERVER

  static method SSL_SESS_CACHE_SERVER : int ();

Gets the value of C<SSL_SESS_CACHE_SERVER>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_ST_ACCEPT

  static method SSL_ST_ACCEPT : int ();

Gets the value of C<SSL_ST_ACCEPT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_ST_BEFORE

  static method SSL_ST_BEFORE : int ();

Gets the value of C<SSL_ST_BEFORE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_ST_CONNECT

  static method SSL_ST_CONNECT : int ();

Gets the value of C<SSL_ST_CONNECT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_ST_INIT

  static method SSL_ST_INIT : int ();

Gets the value of C<SSL_ST_INIT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_ST_OK

  static method SSL_ST_OK : int ();

Gets the value of C<SSL_ST_OK>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_ST_READ_BODY

  static method SSL_ST_READ_BODY : int ();

Gets the value of C<SSL_ST_READ_BODY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_ST_READ_HEADER

  static method SSL_ST_READ_HEADER : int ();

Gets the value of C<SSL_ST_READ_HEADER>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_VERIFY_CLIENT_ONCE

  static method SSL_VERIFY_CLIENT_ONCE : int ();

Gets the value of C<SSL_VERIFY_CLIENT_ONCE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_VERIFY_FAIL_IF_NO_PEER_CERT

  static method SSL_VERIFY_FAIL_IF_NO_PEER_CERT : int ();

Gets the value of C<SSL_VERIFY_FAIL_IF_NO_PEER_CERT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_VERIFY_NONE

  static method SSL_VERIFY_NONE : int ();

Gets the value of C<SSL_VERIFY_NONE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_VERIFY_PEER

  static method SSL_VERIFY_PEER : int ();

Gets the value of C<SSL_VERIFY_PEER>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_VERIFY_POST_HANDSHAKE

  static method SSL_VERIFY_POST_HANDSHAKE : int ();

Gets the value of C<SSL_VERIFY_POST_HANDSHAKE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_WRITING

  static method SSL_WRITING : int ();

Gets the value of C<SSL_WRITING>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SSL_X509_LOOKUP

  static method SSL_X509_LOOKUP : int ();

Gets the value of C<SSL_X509_LOOKUP>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 TLS1_1_VERSION

  static method TLS1_1_VERSION : int ();

Gets the value of C<TLS1_1_VERSION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 TLS1_2_VERSION

  static method TLS1_2_VERSION : int ();

Gets the value of C<TLS1_2_VERSION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 TLS1_3_VERSION

  static method TLS1_3_VERSION : int ();

Gets the value of C<TLS1_3_VERSION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 TLS1_VERSION

  static method TLS1_VERSION : int ();

Gets the value of C<TLS1_VERSION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 TLSEXT_STATUSTYPE_ocsp

  static method TLSEXT_STATUSTYPE_ocsp : int ();

Gets the value of C<TLSEXT_STATUSTYPE_ocsp>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 V_OCSP_CERTSTATUS_GOOD

  static method V_OCSP_CERTSTATUS_GOOD : int ();

Gets the value of C<V_OCSP_CERTSTATUS_GOOD>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 V_OCSP_CERTSTATUS_REVOKED

  static method V_OCSP_CERTSTATUS_REVOKED : int ();

Gets the value of C<V_OCSP_CERTSTATUS_REVOKED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 V_OCSP_CERTSTATUS_UNKNOWN

  static method V_OCSP_CERTSTATUS_UNKNOWN : int ();

Gets the value of C<V_OCSP_CERTSTATUS_UNKNOWN>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_CHECK_FLAG_ALWAYS_CHECK_SUBJECT

  static method X509_CHECK_FLAG_ALWAYS_CHECK_SUBJECT : int ();

Gets the value of C<X509_CHECK_FLAG_ALWAYS_CHECK_SUBJECT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_CHECK_FLAG_MULTI_LABEL_WILDCARDS

  static method X509_CHECK_FLAG_MULTI_LABEL_WILDCARDS : int ();

Gets the value of C<X509_CHECK_FLAG_MULTI_LABEL_WILDCARDS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_CHECK_FLAG_NEVER_CHECK_SUBJECT

  static method X509_CHECK_FLAG_NEVER_CHECK_SUBJECT : int ();

Gets the value of C<X509_CHECK_FLAG_NEVER_CHECK_SUBJECT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_CHECK_FLAG_NO_PARTIAL_WILDCARDS

  static method X509_CHECK_FLAG_NO_PARTIAL_WILDCARDS : int ();

Gets the value of C<X509_CHECK_FLAG_NO_PARTIAL_WILDCARDS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_CHECK_FLAG_NO_WILDCARDS

  static method X509_CHECK_FLAG_NO_WILDCARDS : int ();

Gets the value of C<X509_CHECK_FLAG_NO_WILDCARDS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_CHECK_FLAG_SINGLE_LABEL_SUBDOMAINS

  static method X509_CHECK_FLAG_SINGLE_LABEL_SUBDOMAINS : int ();

Gets the value of C<X509_CHECK_FLAG_SINGLE_LABEL_SUBDOMAINS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_FILETYPE_ASN1

  static method X509_FILETYPE_ASN1 : int ();

Gets the value of C<X509_FILETYPE_ASN1>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_FILETYPE_DEFAULT

  static method X509_FILETYPE_DEFAULT : int ();

Gets the value of C<X509_FILETYPE_DEFAULT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_FILETYPE_PEM

  static method X509_FILETYPE_PEM : int ();

Gets the value of C<X509_FILETYPE_PEM>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_PURPOSE_ANY

  static method X509_PURPOSE_ANY : int ();

Gets the value of C<X509_PURPOSE_ANY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_PURPOSE_CRL_SIGN

  static method X509_PURPOSE_CRL_SIGN : int ();

Gets the value of C<X509_PURPOSE_CRL_SIGN>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_PURPOSE_NS_SSL_SERVER

  static method X509_PURPOSE_NS_SSL_SERVER : int ();

Gets the value of C<X509_PURPOSE_NS_SSL_SERVER>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_PURPOSE_OCSP_HELPER

  static method X509_PURPOSE_OCSP_HELPER : int ();

Gets the value of C<X509_PURPOSE_OCSP_HELPER>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_PURPOSE_SMIME_ENCRYPT

  static method X509_PURPOSE_SMIME_ENCRYPT : int ();

Gets the value of C<X509_PURPOSE_SMIME_ENCRYPT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_PURPOSE_SMIME_SIGN

  static method X509_PURPOSE_SMIME_SIGN : int ();

Gets the value of C<X509_PURPOSE_SMIME_SIGN>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_PURPOSE_SSL_CLIENT

  static method X509_PURPOSE_SSL_CLIENT : int ();

Gets the value of C<X509_PURPOSE_SSL_CLIENT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_PURPOSE_SSL_SERVER

  static method X509_PURPOSE_SSL_SERVER : int ();

Gets the value of C<X509_PURPOSE_SSL_SERVER>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_PURPOSE_TIMESTAMP_SIGN

  static method X509_PURPOSE_TIMESTAMP_SIGN : int ();

Gets the value of C<X509_PURPOSE_TIMESTAMP_SIGN>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_TRUST_COMPAT

  static method X509_TRUST_COMPAT : int ();

Gets the value of C<X509_TRUST_COMPAT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_TRUST_EMAIL

  static method X509_TRUST_EMAIL : int ();

Gets the value of C<X509_TRUST_EMAIL>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_TRUST_OBJECT_SIGN

  static method X509_TRUST_OBJECT_SIGN : int ();

Gets the value of C<X509_TRUST_OBJECT_SIGN>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_TRUST_OCSP_REQUEST

  static method X509_TRUST_OCSP_REQUEST : int ();

Gets the value of C<X509_TRUST_OCSP_REQUEST>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_TRUST_OCSP_SIGN

  static method X509_TRUST_OCSP_SIGN : int ();

Gets the value of C<X509_TRUST_OCSP_SIGN>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_TRUST_SSL_CLIENT

  static method X509_TRUST_SSL_CLIENT : int ();

Gets the value of C<X509_TRUST_SSL_CLIENT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_TRUST_SSL_SERVER

  static method X509_TRUST_SSL_SERVER : int ();

Gets the value of C<X509_TRUST_SSL_SERVER>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_TRUST_TSA

  static method X509_TRUST_TSA : int ();

Gets the value of C<X509_TRUST_TSA>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_AKID_ISSUER_SERIAL_MISMATCH

  static method X509_V_ERR_AKID_ISSUER_SERIAL_MISMATCH : int ();

Gets the value of C<X509_V_ERR_AKID_ISSUER_SERIAL_MISMATCH>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_AKID_SKID_MISMATCH

  static method X509_V_ERR_AKID_SKID_MISMATCH : int ();

Gets the value of C<X509_V_ERR_AKID_SKID_MISMATCH>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_APPLICATION_VERIFICATION

  static method X509_V_ERR_APPLICATION_VERIFICATION : int ();

Gets the value of C<X509_V_ERR_APPLICATION_VERIFICATION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_CA_KEY_TOO_SMALL

  static method X509_V_ERR_CA_KEY_TOO_SMALL : int ();

Gets the value of C<X509_V_ERR_CA_KEY_TOO_SMALL>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_CA_MD_TOO_WEAK

  static method X509_V_ERR_CA_MD_TOO_WEAK : int ();

Gets the value of C<X509_V_ERR_CA_MD_TOO_WEAK>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_CERT_CHAIN_TOO_LONG

  static method X509_V_ERR_CERT_CHAIN_TOO_LONG : int ();

Gets the value of C<X509_V_ERR_CERT_CHAIN_TOO_LONG>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_CERT_HAS_EXPIRED

  static method X509_V_ERR_CERT_HAS_EXPIRED : int ();

Gets the value of C<X509_V_ERR_CERT_HAS_EXPIRED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_CERT_NOT_YET_VALID

  static method X509_V_ERR_CERT_NOT_YET_VALID : int ();

Gets the value of C<X509_V_ERR_CERT_NOT_YET_VALID>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_CERT_REJECTED

  static method X509_V_ERR_CERT_REJECTED : int ();

Gets the value of C<X509_V_ERR_CERT_REJECTED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_CERT_REVOKED

  static method X509_V_ERR_CERT_REVOKED : int ();

Gets the value of C<X509_V_ERR_CERT_REVOKED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_CERT_SIGNATURE_FAILURE

  static method X509_V_ERR_CERT_SIGNATURE_FAILURE : int ();

Gets the value of C<X509_V_ERR_CERT_SIGNATURE_FAILURE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_CERT_UNTRUSTED

  static method X509_V_ERR_CERT_UNTRUSTED : int ();

Gets the value of C<X509_V_ERR_CERT_UNTRUSTED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_CRL_HAS_EXPIRED

  static method X509_V_ERR_CRL_HAS_EXPIRED : int ();

Gets the value of C<X509_V_ERR_CRL_HAS_EXPIRED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_CRL_NOT_YET_VALID

  static method X509_V_ERR_CRL_NOT_YET_VALID : int ();

Gets the value of C<X509_V_ERR_CRL_NOT_YET_VALID>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_CRL_PATH_VALIDATION_ERROR

  static method X509_V_ERR_CRL_PATH_VALIDATION_ERROR : int ();

Gets the value of C<X509_V_ERR_CRL_PATH_VALIDATION_ERROR>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_CRL_SIGNATURE_FAILURE

  static method X509_V_ERR_CRL_SIGNATURE_FAILURE : int ();

Gets the value of C<X509_V_ERR_CRL_SIGNATURE_FAILURE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_DANE_NO_MATCH

  static method X509_V_ERR_DANE_NO_MATCH : int ();

Gets the value of C<X509_V_ERR_DANE_NO_MATCH>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_DEPTH_ZERO_SELF_SIGNED_CERT

  static method X509_V_ERR_DEPTH_ZERO_SELF_SIGNED_CERT : int ();

Gets the value of C<X509_V_ERR_DEPTH_ZERO_SELF_SIGNED_CERT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_DIFFERENT_CRL_SCOPE

  static method X509_V_ERR_DIFFERENT_CRL_SCOPE : int ();

Gets the value of C<X509_V_ERR_DIFFERENT_CRL_SCOPE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_EE_KEY_TOO_SMALL

  static method X509_V_ERR_EE_KEY_TOO_SMALL : int ();

Gets the value of C<X509_V_ERR_EE_KEY_TOO_SMALL>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_EMAIL_MISMATCH

  static method X509_V_ERR_EMAIL_MISMATCH : int ();

Gets the value of C<X509_V_ERR_EMAIL_MISMATCH>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_ERROR_IN_CERT_NOT_AFTER_FIELD

  static method X509_V_ERR_ERROR_IN_CERT_NOT_AFTER_FIELD : int ();

Gets the value of C<X509_V_ERR_ERROR_IN_CERT_NOT_AFTER_FIELD>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_ERROR_IN_CERT_NOT_BEFORE_FIELD

  static method X509_V_ERR_ERROR_IN_CERT_NOT_BEFORE_FIELD : int ();

Gets the value of C<X509_V_ERR_ERROR_IN_CERT_NOT_BEFORE_FIELD>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_ERROR_IN_CRL_LAST_UPDATE_FIELD

  static method X509_V_ERR_ERROR_IN_CRL_LAST_UPDATE_FIELD : int ();

Gets the value of C<X509_V_ERR_ERROR_IN_CRL_LAST_UPDATE_FIELD>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_ERROR_IN_CRL_NEXT_UPDATE_FIELD

  static method X509_V_ERR_ERROR_IN_CRL_NEXT_UPDATE_FIELD : int ();

Gets the value of C<X509_V_ERR_ERROR_IN_CRL_NEXT_UPDATE_FIELD>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_EXCLUDED_VIOLATION

  static method X509_V_ERR_EXCLUDED_VIOLATION : int ();

Gets the value of C<X509_V_ERR_EXCLUDED_VIOLATION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_HOSTNAME_MISMATCH

  static method X509_V_ERR_HOSTNAME_MISMATCH : int ();

Gets the value of C<X509_V_ERR_HOSTNAME_MISMATCH>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_INVALID_CA

  static method X509_V_ERR_INVALID_CA : int ();

Gets the value of C<X509_V_ERR_INVALID_CA>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_INVALID_CALL

  static method X509_V_ERR_INVALID_CALL : int ();

Gets the value of C<X509_V_ERR_INVALID_CALL>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_INVALID_EXTENSION

  static method X509_V_ERR_INVALID_EXTENSION : int ();

Gets the value of C<X509_V_ERR_INVALID_EXTENSION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_INVALID_NON_CA

  static method X509_V_ERR_INVALID_NON_CA : int ();

Gets the value of C<X509_V_ERR_INVALID_NON_CA>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_INVALID_POLICY_EXTENSION

  static method X509_V_ERR_INVALID_POLICY_EXTENSION : int ();

Gets the value of C<X509_V_ERR_INVALID_POLICY_EXTENSION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_INVALID_PURPOSE

  static method X509_V_ERR_INVALID_PURPOSE : int ();

Gets the value of C<X509_V_ERR_INVALID_PURPOSE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_IP_ADDRESS_MISMATCH

  static method X509_V_ERR_IP_ADDRESS_MISMATCH : int ();

Gets the value of C<X509_V_ERR_IP_ADDRESS_MISMATCH>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_KEYUSAGE_NO_CERTSIGN

  static method X509_V_ERR_KEYUSAGE_NO_CERTSIGN : int ();

Gets the value of C<X509_V_ERR_KEYUSAGE_NO_CERTSIGN>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_KEYUSAGE_NO_CRL_SIGN

  static method X509_V_ERR_KEYUSAGE_NO_CRL_SIGN : int ();

Gets the value of C<X509_V_ERR_KEYUSAGE_NO_CRL_SIGN>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_KEYUSAGE_NO_DIGITAL_SIGNATURE

  static method X509_V_ERR_KEYUSAGE_NO_DIGITAL_SIGNATURE : int ();

Gets the value of C<X509_V_ERR_KEYUSAGE_NO_DIGITAL_SIGNATURE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_NO_EXPLICIT_POLICY

  static method X509_V_ERR_NO_EXPLICIT_POLICY : int ();

Gets the value of C<X509_V_ERR_NO_EXPLICIT_POLICY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_NO_VALID_SCTS

  static method X509_V_ERR_NO_VALID_SCTS : int ();

Gets the value of C<X509_V_ERR_NO_VALID_SCTS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_OCSP_CERT_UNKNOWN

  static method X509_V_ERR_OCSP_CERT_UNKNOWN : int ();

Gets the value of C<X509_V_ERR_OCSP_CERT_UNKNOWN>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_OCSP_VERIFY_FAILED

  static method X509_V_ERR_OCSP_VERIFY_FAILED : int ();

Gets the value of C<X509_V_ERR_OCSP_VERIFY_FAILED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_OCSP_VERIFY_NEEDED

  static method X509_V_ERR_OCSP_VERIFY_NEEDED : int ();

Gets the value of C<X509_V_ERR_OCSP_VERIFY_NEEDED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_OUT_OF_MEM

  static method X509_V_ERR_OUT_OF_MEM : int ();

Gets the value of C<X509_V_ERR_OUT_OF_MEM>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_PATH_LENGTH_EXCEEDED

  static method X509_V_ERR_PATH_LENGTH_EXCEEDED : int ();

Gets the value of C<X509_V_ERR_PATH_LENGTH_EXCEEDED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_PATH_LOOP

  static method X509_V_ERR_PATH_LOOP : int ();

Gets the value of C<X509_V_ERR_PATH_LOOP>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_PERMITTED_VIOLATION

  static method X509_V_ERR_PERMITTED_VIOLATION : int ();

Gets the value of C<X509_V_ERR_PERMITTED_VIOLATION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_PROXY_CERTIFICATES_NOT_ALLOWED

  static method X509_V_ERR_PROXY_CERTIFICATES_NOT_ALLOWED : int ();

Gets the value of C<X509_V_ERR_PROXY_CERTIFICATES_NOT_ALLOWED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_PROXY_PATH_LENGTH_EXCEEDED

  static method X509_V_ERR_PROXY_PATH_LENGTH_EXCEEDED : int ();

Gets the value of C<X509_V_ERR_PROXY_PATH_LENGTH_EXCEEDED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_PROXY_SUBJECT_NAME_VIOLATION

  static method X509_V_ERR_PROXY_SUBJECT_NAME_VIOLATION : int ();

Gets the value of C<X509_V_ERR_PROXY_SUBJECT_NAME_VIOLATION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_SELF_SIGNED_CERT_IN_CHAIN

  static method X509_V_ERR_SELF_SIGNED_CERT_IN_CHAIN : int ();

Gets the value of C<X509_V_ERR_SELF_SIGNED_CERT_IN_CHAIN>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_STORE_LOOKUP

  static method X509_V_ERR_STORE_LOOKUP : int ();

Gets the value of C<X509_V_ERR_STORE_LOOKUP>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_SUBJECT_ISSUER_MISMATCH

  static method X509_V_ERR_SUBJECT_ISSUER_MISMATCH : int ();

Gets the value of C<X509_V_ERR_SUBJECT_ISSUER_MISMATCH>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_SUBTREE_MINMAX

  static method X509_V_ERR_SUBTREE_MINMAX : int ();

Gets the value of C<X509_V_ERR_SUBTREE_MINMAX>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_SUITE_B_CANNOT_SIGN_P_384_WITH_P_256

  static method X509_V_ERR_SUITE_B_CANNOT_SIGN_P_384_WITH_P_256 : int ();

Gets the value of C<X509_V_ERR_SUITE_B_CANNOT_SIGN_P_384_WITH_P_256>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_SUITE_B_INVALID_ALGORITHM

  static method X509_V_ERR_SUITE_B_INVALID_ALGORITHM : int ();

Gets the value of C<X509_V_ERR_SUITE_B_INVALID_ALGORITHM>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_SUITE_B_INVALID_CURVE

  static method X509_V_ERR_SUITE_B_INVALID_CURVE : int ();

Gets the value of C<X509_V_ERR_SUITE_B_INVALID_CURVE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_SUITE_B_INVALID_SIGNATURE_ALGORITHM

  static method X509_V_ERR_SUITE_B_INVALID_SIGNATURE_ALGORITHM : int ();

Gets the value of C<X509_V_ERR_SUITE_B_INVALID_SIGNATURE_ALGORITHM>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_SUITE_B_INVALID_VERSION

  static method X509_V_ERR_SUITE_B_INVALID_VERSION : int ();

Gets the value of C<X509_V_ERR_SUITE_B_INVALID_VERSION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_SUITE_B_LOS_NOT_ALLOWED

  static method X509_V_ERR_SUITE_B_LOS_NOT_ALLOWED : int ();

Gets the value of C<X509_V_ERR_SUITE_B_LOS_NOT_ALLOWED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_UNABLE_TO_DECODE_ISSUER_PUBLIC_KEY

  static method X509_V_ERR_UNABLE_TO_DECODE_ISSUER_PUBLIC_KEY : int ();

Gets the value of C<X509_V_ERR_UNABLE_TO_DECODE_ISSUER_PUBLIC_KEY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_UNABLE_TO_DECRYPT_CERT_SIGNATURE

  static method X509_V_ERR_UNABLE_TO_DECRYPT_CERT_SIGNATURE : int ();

Gets the value of C<X509_V_ERR_UNABLE_TO_DECRYPT_CERT_SIGNATURE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_UNABLE_TO_DECRYPT_CRL_SIGNATURE

  static method X509_V_ERR_UNABLE_TO_DECRYPT_CRL_SIGNATURE : int ();

Gets the value of C<X509_V_ERR_UNABLE_TO_DECRYPT_CRL_SIGNATURE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_UNABLE_TO_GET_CRL

  static method X509_V_ERR_UNABLE_TO_GET_CRL : int ();

Gets the value of C<X509_V_ERR_UNABLE_TO_GET_CRL>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_UNABLE_TO_GET_CRL_ISSUER

  static method X509_V_ERR_UNABLE_TO_GET_CRL_ISSUER : int ();

Gets the value of C<X509_V_ERR_UNABLE_TO_GET_CRL_ISSUER>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT

  static method X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT : int ();

Gets the value of C<X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT_LOCALLY

  static method X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT_LOCALLY : int ();

Gets the value of C<X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT_LOCALLY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE

  static method X509_V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE : int ();

Gets the value of C<X509_V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_UNHANDLED_CRITICAL_CRL_EXTENSION

  static method X509_V_ERR_UNHANDLED_CRITICAL_CRL_EXTENSION : int ();

Gets the value of C<X509_V_ERR_UNHANDLED_CRITICAL_CRL_EXTENSION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_UNHANDLED_CRITICAL_EXTENSION

  static method X509_V_ERR_UNHANDLED_CRITICAL_EXTENSION : int ();

Gets the value of C<X509_V_ERR_UNHANDLED_CRITICAL_EXTENSION>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_UNNESTED_RESOURCE

  static method X509_V_ERR_UNNESTED_RESOURCE : int ();

Gets the value of C<X509_V_ERR_UNNESTED_RESOURCE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_UNSPECIFIED

  static method X509_V_ERR_UNSPECIFIED : int ();

Gets the value of C<X509_V_ERR_UNSPECIFIED>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_UNSUPPORTED_CONSTRAINT_SYNTAX

  static method X509_V_ERR_UNSUPPORTED_CONSTRAINT_SYNTAX : int ();

Gets the value of C<X509_V_ERR_UNSUPPORTED_CONSTRAINT_SYNTAX>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_UNSUPPORTED_CONSTRAINT_TYPE

  static method X509_V_ERR_UNSUPPORTED_CONSTRAINT_TYPE : int ();

Gets the value of C<X509_V_ERR_UNSUPPORTED_CONSTRAINT_TYPE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_UNSUPPORTED_EXTENSION_FEATURE

  static method X509_V_ERR_UNSUPPORTED_EXTENSION_FEATURE : int ();

Gets the value of C<X509_V_ERR_UNSUPPORTED_EXTENSION_FEATURE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_ERR_UNSUPPORTED_NAME_SYNTAX

  static method X509_V_ERR_UNSUPPORTED_NAME_SYNTAX : int ();

Gets the value of C<X509_V_ERR_UNSUPPORTED_NAME_SYNTAX>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_ALLOW_PROXY_CERTS

  static method X509_V_FLAG_ALLOW_PROXY_CERTS : int ();

Gets the value of C<X509_V_FLAG_ALLOW_PROXY_CERTS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_CB_ISSUER_CHECK

  static method X509_V_FLAG_CB_ISSUER_CHECK : int ();

Gets the value of C<X509_V_FLAG_CB_ISSUER_CHECK>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_CHECK_SS_SIGNATURE

  static method X509_V_FLAG_CHECK_SS_SIGNATURE : int ();

Gets the value of C<X509_V_FLAG_CHECK_SS_SIGNATURE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_CRL_CHECK

  static method X509_V_FLAG_CRL_CHECK : int ();

Gets the value of C<X509_V_FLAG_CRL_CHECK>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_CRL_CHECK_ALL

  static method X509_V_FLAG_CRL_CHECK_ALL : int ();

Gets the value of C<X509_V_FLAG_CRL_CHECK_ALL>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_EXPLICIT_POLICY

  static method X509_V_FLAG_EXPLICIT_POLICY : int ();

Gets the value of C<X509_V_FLAG_EXPLICIT_POLICY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_EXTENDED_CRL_SUPPORT

  static method X509_V_FLAG_EXTENDED_CRL_SUPPORT : int ();

Gets the value of C<X509_V_FLAG_EXTENDED_CRL_SUPPORT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_IGNORE_CRITICAL

  static method X509_V_FLAG_IGNORE_CRITICAL : int ();

Gets the value of C<X509_V_FLAG_IGNORE_CRITICAL>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_INHIBIT_ANY

  static method X509_V_FLAG_INHIBIT_ANY : int ();

Gets the value of C<X509_V_FLAG_INHIBIT_ANY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_INHIBIT_MAP

  static method X509_V_FLAG_INHIBIT_MAP : int ();

Gets the value of C<X509_V_FLAG_INHIBIT_MAP>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_LEGACY_VERIFY

  static method X509_V_FLAG_LEGACY_VERIFY : int ();

Gets the value of C<X509_V_FLAG_LEGACY_VERIFY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_NOTIFY_POLICY

  static method X509_V_FLAG_NOTIFY_POLICY : int ();

Gets the value of C<X509_V_FLAG_NOTIFY_POLICY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_NO_ALT_CHAINS

  static method X509_V_FLAG_NO_ALT_CHAINS : int ();

Gets the value of C<X509_V_FLAG_NO_ALT_CHAINS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_NO_CHECK_TIME

  static method X509_V_FLAG_NO_CHECK_TIME : int ();

Gets the value of C<X509_V_FLAG_NO_CHECK_TIME>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_PARTIAL_CHAIN

  static method X509_V_FLAG_PARTIAL_CHAIN : int ();

Gets the value of C<X509_V_FLAG_PARTIAL_CHAIN>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_POLICY_CHECK

  static method X509_V_FLAG_POLICY_CHECK : int ();

Gets the value of C<X509_V_FLAG_POLICY_CHECK>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_POLICY_MASK

  static method X509_V_FLAG_POLICY_MASK : int ();

Gets the value of C<X509_V_FLAG_POLICY_MASK>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_SUITEB_128_LOS

  static method X509_V_FLAG_SUITEB_128_LOS : int ();

Gets the value of C<X509_V_FLAG_SUITEB_128_LOS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_SUITEB_128_LOS_ONLY

  static method X509_V_FLAG_SUITEB_128_LOS_ONLY : int ();

Gets the value of C<X509_V_FLAG_SUITEB_128_LOS_ONLY>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_SUITEB_192_LOS

  static method X509_V_FLAG_SUITEB_192_LOS : int ();

Gets the value of C<X509_V_FLAG_SUITEB_192_LOS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_TRUSTED_FIRST

  static method X509_V_FLAG_TRUSTED_FIRST : int ();

Gets the value of C<X509_V_FLAG_TRUSTED_FIRST>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_USE_CHECK_TIME

  static method X509_V_FLAG_USE_CHECK_TIME : int ();

Gets the value of C<X509_V_FLAG_USE_CHECK_TIME>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_USE_DELTAS

  static method X509_V_FLAG_USE_DELTAS : int ();

Gets the value of C<X509_V_FLAG_USE_DELTAS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_FLAG_X509_STRICT

  static method X509_V_FLAG_X509_STRICT : int ();

Gets the value of C<X509_V_FLAG_X509_STRICT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 X509_V_OK

  static method X509_V_OK : int ();

Gets the value of C<X509_V_OK>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 XN_FLAG_COMPAT

  static method XN_FLAG_COMPAT : int ();

Gets the value of C<XN_FLAG_COMPAT>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 XN_FLAG_DN_REV

  static method XN_FLAG_DN_REV : int ();

Gets the value of C<XN_FLAG_DN_REV>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 XN_FLAG_DUMP_UNKNOWN_FIELDS

  static method XN_FLAG_DUMP_UNKNOWN_FIELDS : int ();

Gets the value of C<XN_FLAG_DUMP_UNKNOWN_FIELDS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 XN_FLAG_FN_ALIGN

  static method XN_FLAG_FN_ALIGN : int ();

Gets the value of C<XN_FLAG_FN_ALIGN>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 XN_FLAG_FN_LN

  static method XN_FLAG_FN_LN : int ();

Gets the value of C<XN_FLAG_FN_LN>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 XN_FLAG_FN_MASK

  static method XN_FLAG_FN_MASK : int ();

Gets the value of C<XN_FLAG_FN_MASK>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 XN_FLAG_FN_NONE

  static method XN_FLAG_FN_NONE : int ();

Gets the value of C<XN_FLAG_FN_NONE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 XN_FLAG_FN_OID

  static method XN_FLAG_FN_OID : int ();

Gets the value of C<XN_FLAG_FN_OID>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 XN_FLAG_FN_SN

  static method XN_FLAG_FN_SN : int ();

Gets the value of C<XN_FLAG_FN_SN>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 XN_FLAG_MULTILINE

  static method XN_FLAG_MULTILINE : int ();

Gets the value of C<XN_FLAG_MULTILINE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 XN_FLAG_ONELINE

  static method XN_FLAG_ONELINE : int ();

Gets the value of C<XN_FLAG_ONELINE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 XN_FLAG_RFC2253

  static method XN_FLAG_RFC2253 : int ();

Gets the value of C<XN_FLAG_RFC2253>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 XN_FLAG_SEP_COMMA_PLUS

  static method XN_FLAG_SEP_COMMA_PLUS : int ();

Gets the value of C<XN_FLAG_SEP_COMMA_PLUS>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 XN_FLAG_SEP_CPLUS_SPC

  static method XN_FLAG_SEP_CPLUS_SPC : int ();

Gets the value of C<XN_FLAG_SEP_CPLUS_SPC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 XN_FLAG_SEP_MASK

  static method XN_FLAG_SEP_MASK : int ();

Gets the value of C<XN_FLAG_SEP_MASK>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 XN_FLAG_SEP_MULTILINE

  static method XN_FLAG_SEP_MULTILINE : int ();

Gets the value of C<XN_FLAG_SEP_MULTILINE>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 XN_FLAG_SEP_SPLUS_SPC

  static method XN_FLAG_SEP_SPLUS_SPC : int ();

Gets the value of C<XN_FLAG_SEP_SPLUS_SPC>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 XN_FLAG_SPC_EQ

  static method XN_FLAG_SPC_EQ : int ();

Gets the value of C<XN_FLAG_SPC_EQ>. If this constant value is not defined on this system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head1 Copyright & License

Copyright (c) 2023 Yuki Kimoto

MIT License

